/* ***** BEGIN LICENSE BLOCK *****
 * Licensed under Version: MPL 1.1/GPL 2.0/LGPL 2.1
 * Full Terms at http://mozile.mozdev.org/license.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Playsophy code.
 *
 * The Initial Developer of the Original Code is Playsophy
 * Portions created by the Initial Developer are Copyright (C) 2002-2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *		Karl Guertin <grayrest@grayrest.com>
 *		James A. Overton <james@overton.ca>
 *		Christian Stocker (Bitflux)
 *		Paul Everitt
 *		David Palm
 *
 * ***** END LICENSE BLOCK ***** */

/**
@fileoverview
Utitlity functions.
*/


var mozileDebugArray = new Array();

/**
Mozile Debug Levels.
0 = Really important, alert the user right away, add to debug array
1 = Important, always show this in the status, add to debug array
2 = Not important, add to debug array
3 = Unimportant, add to debug array
*/
function mozileDebug(f,level,msg,minimise) {
	var mozileDebugLevel = mozilePrefs.getIntPref("mozile.debugLevelInt");
	
	// act only if the level of the message is higher than the mozileDebugLevel
	
	if( (level > 1 && mozileDebugLevel < 1) || (level > 2 && mozileDebugLevel < 2) ) {
		// Ignore these debug events
	}
	else {
		// Log to the debugging array	
		var datestamp = 
		mozileDD('FullYear')	+"-"+
		mozileDD('Month')			+"-"+
		mozileDD('Date')			+" "+
		mozileDD('Hours')			+":"+
		mozileDD('Minutes')		+":"+
		mozileDD('Seconds');

		var entry = new Array(datestamp,f,level,msg);
		mozileDebugArray.push(entry);

		// Critical behaviours
		if(level <= 1) {
  		var message = "Mozile: ["+ f +"] "+ msg; 
  		if(level == 0) {
				minimise ? alert(msg) : alert(message);
  		}	else { //level==1
  			window.status = message.substr(0,250);
  		}
		}
	}
}

	// Returns date strings as two digits (with leading "0") if they are 1 digit long
var mozileDates = new Object();

function mozileDD(command) {
		// first see if we've already recorded it...
	if(command in mozileDates) {
		return mozileDates[command];
	}
	
	var d = new Date();
	var commandString = "d.get"+command+"()";
	var str = eval(commandString)+"";
	if(str.length==1) {
		str = "0"+str;
	}
	if(command=="FullYear" || command=="Month" || command=="Date") {
		mozileDates[command]=str;
	}

	return str;
}

function mozileDebugAlert() {
	alert(mozileDebugArray);
}

/* To Do: Find a better way so this can go. */
function printXML(XML) {
	var objXMLSerializer = new XMLSerializer;
	var output = objXMLSerializer.serializeToString(XML);
		// fix stupid uppercase tags!
	output = output.replace( /<(\/?)([A-Z]+)/g,
		function (output,p1,p2,offset,s) {
			return '<'+p1+p2.toLowerCase() ;
		} ) ;
	return output;
}

function mozileGetContext(sel) {
	var f = ["mozileUtilities.js","mozileGetContext"];

	try {
		if ( sel.anchorNode != null ) {
		  var aN = sel.anchorNode;
			if( aN.nodeType == Node.ELEMENT_NODE ) {
//				mozileDebug(f,3,"Selection anchorNode: "+aN.nodeName);
				return aN;
 			}
 			if ( aN.parentNode != null ) {
				var aNpN = aN.parentNode;
   			if( aNpN.nodeType == Node.ELEMENT_NODE ) {
// 					mozileDebug(f,3,"Selection parentNode: "+aNpN.nodeName);
   				return aNpN;
   			}
			}
		}
		else {
			mozileDebug(f,0,"No Node!");
		}
	}
	catch(e) {
		mozileDebug(f,0,"Exception: "+e);
		return null;
	}
	return null;
}


function mozileRemoveChildren(node) {	
	var f = ["mozileUtilities.js","mozileRemoveChildren"];
	try {
		if(node.hasChildNodes()) {
			while(node.hasChildNodes()) {
				node.removeChild(node.lastChild);
			}
		}
	} catch(e) {
		mozileDebug(f,0,"Error: "+e);
	}
	return node;
}


/**
Insert single Unicode character.

@param {number} charCode
*/
function mozileInsertChar( charCode ) {
	var f = ["mozileUtilities.js","mozileInsertChar"];
	try {
		mozileDoTyping();
		mozileSelection.insertCharacter( charCode );
		mozileMarkupInput();
	} catch (e) {
		mozileDebug(f,0,"Exception inserting char: "+e);
	}
}

/**
Custom Mozile Dialog.

To be expanded as needed.
*/
function mozileDialog( content ) {
	var win = window.openDialog("chrome://mozile/content/XUL/mdialog.xul",
		"moziledialog", "modal,centerscreen,chrome,resizable=no", content );
}

/**
Opens a file in the current browser window, a new tab, or a new window.
*/
function mozileOpen( location, method ) {
	var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"].getService(Components.interfaces.nsIWindowMediator);
	var mrw = wm.getMostRecentWindow("navigator:browser");
	switch ( method ) {
		case "window":
			window.open(location)
			break;
		case "tab":
			var browser = mrw.getBrowser();
			browser.addTab(location);
			break;
		default: //"browser"
			mrw.content.window.location=location;
	}
}
/**
Opens a file via a context popup menu.
*/
function mozileOpenNew( method ) {
	var popupNode = document.popupNode;
	var id = popupNode.getAttribute( "id" );
	var location;
	switch ( method ) {
		case "window":
		case "tab":
		case "browser":
			break;
		default:
			method="window";
	}
	switch ( id ) {
		case "mozile-demo":
			location = MOZILEC.DEMO;
			break;
		case "mozile-home":
			location = MOZILEC.HOME;
			break;
		default: //"mozile-help"
			location = MOZILEC.HELP;
	}
	mozileOpen( location, method );
}

/**
Closes the context menu and the original menu.
Not sure why this doesn't happen automatically. 
*/
function mozileHidePopup(event) {
	document.getElementById("mozile-menu-popup").hidePopup();
}